@@ -12,7 +12,7 @@ test_that("Reuse previous GUM on N1234$x", {
 })
 
 # Test some crazy order of GUM
-testModel <- gum(Mcomp::M3$N1234$x, orders=c(1,1,1), lags=c(1,3,5), h=18, holdout=TRUE, initial="o", silent=TRUE, intervals=TRUE)
+testModel <- gum(Mcomp::M3$N1234$x, orders=c(1,1,1), lags=c(1,3,5), h=18, holdout=TRUE, initial="o", silent=TRUE, interval=TRUE)
 test_that("Test if crazy order GUM was estimated on N1234$x", {
     expect_equal(testModel$model, "GUM(1[1],1[3],1[5])");
 })
@@ -28,7 +28,7 @@ test_that("Test initials, measurement, transition and persistence of GUM on N256
 # Test exogenous (normal + updateX) with GUM
 x <- cbind(c(rep(0,25),1,rep(0,43)),c(rep(0,10),1,rep(0,58)));
 y <- ts(c(Mcomp::M3$N1457$x,Mcomp::M3$N1457$xx),frequency=12);
-testModel <- gum(y, h=18, holdout=TRUE, xreg=x, updateX=TRUE, silent=TRUE, cfType="aTMSE", intervals="np")
+testModel <- gum(y, h=18, holdout=TRUE, xreg=x, updateX=TRUE, silent=TRUE, loss="aTMSE", interval="np")
 test_that("Check exogenous variables for GUMX on N1457", {
     expect_equal(suppressWarnings(gum(y, h=18, holdout=TRUE, xreg=x, silent=TRUE)$model), testModel$model);
     expect_equal(suppressWarnings(forecast(testModel, h=18, holdout=FALSE)$method), testModel$model);
